*****************************************************************************************************************
**** Replication File for: Remote-learning, Time-Use, and Mental Health of Ecuadorian High-School Students   ****
**** during the COVID-19 Quarantine                                                                          ****
***** Igor Asanov, Francisco Flores, David McKenzie, Mona Mensmann, Mathis Schulte                           ****
*** Journal: World Development **********************************************************************************

*** Analysis is in Stata version 16.1

* set Stata version
version 16.1

*** set directory
cd "C:\Users\wb200090\OneDrive - WBG\otherresearch\Ecuador\CovidSurvey\"

use "EcuadorPublicUse.dta", clear



*********************************************************************************************************
************* SECTION 2: REPORT ON SURVEY RESPONSE RATES AND WHO ANSWERS ETC. ***************************
*********************************************************************************************************

***** Overall Survey Response Rate
sum answersurvey

**** Break down of interview results
fre A1
gen reasonresponse=0 if A1==1
replace reasonresponse=1 if A1==2|A1==5
replace reasonresponse=2 if A1==3|A1==6|A1==7|A1==9|A1==11|A1==14|A1==15|A1==17|A1==18
replace reasonresponse=3 if A1==8
replace reasonresponse=4 if A1==4|A1==12|A1==13
replace reasonresponse=5 if A1==7|A1==10|A1==16|A1==96|A1==.
label define reason1 0 "Answered" 1 "Refused" 2 "Incorrect/Nonexistent number" 3 "Voicemail" 4 "No answer" 5 "Other"
label values reasonresponse reason1
fre reasonresponse


**** Look at Characteristics for those who answer survey and those who don't
* Male and Female
gen male=I_Male=="1"
gen female=I_Male=="0"
replace male=. if I_Male==""|I_Male=="NA"
replace female=. if I_Male==""|I_Male=="NA"

*** Region of country
gen subreg=substr(distrito,1,2)
tab subreg
gen Pichincha=subreg=="17"
gen Napo=subreg=="15"
gen Orellana=subreg=="22"
gen NaOrellana=Napo==1|Orellana==1


*** Wealth Quartiles
destring I_10_Income, force replace
xtile incquart=I_10_Income, nq(4)
gen iq1=incquart==1
gen iq2=incquart==2
gen iq3=incquart==3
gen iq4=incquart==4
for num 1/4: replace iqX=. if I_10_Income==.

* mother's education
destring IV_Mother_edu_Secundariaomenor, force replace
gen loweduc=IV_Mother_edu_Secundariaomenor==1
gen higheduc=IV_Mother_edu_Secundariaomenor==0
replace loweduc=. if IV_Mother_edu_Secundariaomenor==.
replace higheduc=. if IV_Mother_edu_Secundariaomenor==.

* ethnicity
gen mestizowhite=I_Ethnicity_Mestizo=="1"|I_Ethnicity_Blanco=="1"
gen otherethnic=mestizowhite==0
replace mestizowhite=. if I_Ethnicity_Blanco=="NA"
replace otherethnic=. if I_Ethnicity_Blanco=="NA"

*Grade
destring Gradex, force replace
gen grade1=Gradex==1
gen grade2=Gradex==2
gen grade3=Gradex==3
replace grade1=. if Gradex==.
replace grade2=. if Gradex==.
replace grade3=. if Gradex==.

* Age
destring I_Agey, force replace

* Language
destring I_Language_Solo_lengua_nativa, force replace

*** Summarize responses by characteristics

* check also those who take more attempts to respond versus less
gen firstresponse= 1 if answersurvey==1 & nattempts==1
replace firstresponse=0 if answersurvey==1 & nattempts>1

*** Appendix Table 1: Baseline Characteristics by Response Status
mat y = J(22,6,.)
local j=1
foreach var of varlist male female I_Agey iq1 iq2 iq3 iq4 loweduc higheduc mestizowhite otherethnic Pichincha Napo Orellana havephone dadphone mumphone grade1 grade2 grade3  I_Language_Solo_lengua_nativa {
sum `var' if answersurvey==1 
mat y[`j',1]=r(mean)
sum `var' if answersurvey==0
mat y[`j',2]=r(mean)
ttest `var', by(answersurvey)
mat y[`j',3]=r(p)
sum `var' if firstresponse==1 
mat y[`j',4]=r(mean)
sum `var' if firstresponse==0
mat y[`j',5]=r(mean)
ttest `var' if answersurvey==1, by(firstresponse)
mat y[`j',6]=r(p)


local j=`j'+1
}
* Sample Sizes
count if answersurvey==1
mat y[22,1]=r(N)
count if answersurvey==0
mat y[22,2]=r(N)
count if firstresponse==1
mat y[22,4]=r(N)
count if firstresponse==0
mat y[22,5]=r(N)
mat rownames y = "Male" "Female" "Age" "Lowest Wealth Quartile" "Second Wealth Quartile" "Third Wealth Quartile" "Top Wealth Quartile" "Mother's education: high school or less" "Mother's education: beyond high school'" "Mestizo or White ethnicity" "Indigenous or Other Ethnicity" "Pichincha Province" "Napo Province" "Orellana Province" "Student has phone number" "Father has phone number" "Mother has phone number" "Grade 10" "Grade 11" "Grade 12"  "Only speaks native language" "Sample Size"
mat colnames y = "Answer" "Don't Answer" "p-value" "First response" "Multiple attempts" "p-value"
mat2txt, matrix(y) saving("output/TableA1_Answers.xls") format(%9.2f %9.2f %9.3f) replace


**** Describe some of survey logistics **********
*** Number of Enumerators ****
tab A3 answersurvey

*** When did interviews take place? ****
* Graph of completed interviews per day
preserve
collapse (sum) answersurvey, by(dayinterview)
sum answersurvey, de
twoway scatter answersurvey dayinterview, xtitle("Interview date") ytitle("Number of interviews")
restore

**** How long did each interview take? 
gen interviewtime=(datestamp-startdate)/60000
label var interviewtime "Interview time in minutes"
sum interviewtime if answersurvey==0, de
sum interviewtime if answersurvey==1, de

**************************************************************************************************************
******* SECTION 3: ACCESS TO AND USE OF REMOTE LEARNING TECHNOLOGIES *****************************************
**************************************************************************************************************

** What do they have in their house?
gen computer=cond(P4_1==1,1,0) if P4_1~=.
gen internet=cond(P4_2==1,1,0) if P4_2~=.
gen cellphone=cond(P4_3==1,1,0) if P4_3~=.
gen tv=cond(P4_4==1,1,0) if P4_4~=.
gen radio=cond(P4_5==1,1,0) if P4_5~=.
sum computer-radio if answersurvey==1

*** Define access as having computer and internet
gen haveaccess=computer==1 & internet==1
replace haveaccess=. if computer==.|internet==.
label var haveaccess "Have access to computer and internet"

gen allsample=1 if answersurvey==1


********* TABLE 1: Access to Remote Learning Technologies ***************

preserve 
keep if answersurvey==1
*** Summarize access by some characteristics
mat y = J(14,7,.)
count if allsample==1
mat y[1,1]=r(N)
sum computer 
mat y[1,2]=r(mean)
sum internet 
mat y[1,3]=r(mean)
sum tv 
mat y[1,4]=r(mean)
sum radio 
mat y[1,5]=r(mean)
sum haveaccess 
mat y[1,6]=r(mean)

local j=2
foreach var of varlist male female grade1 grade2 grade3 iq1 iq4 loweduc higheduc mestizowhite otherethnic Pichincha NaOrellana {
count if `var'==1
mat y[`j',1]=r(N)
sum computer if `var'==1
mat y[`j',2]=r(mean)
sum internet if `var'==1
mat y[`j',3]=r(mean)
sum tv if `var'==1
mat y[`j',4]=r(mean)
sum radio if `var'==1
mat y[`j',5]=r(mean)
sum haveaccess if `var'==1
mat y[`j',6]=r(mean)
ttest haveaccess, by(`var')
mat y[`j',7]=r(p)

local j=`j'+1
}
mat rownames y = "Full Sample" "Males" "Females" "Grade 10" "Grade 11" "Grade 12" "Lowest Wealth Quartile" "Highest Wealth Quartile" "Mother's Education: high school or less" "Mother's education: beyond high school" "Mestizo or White" "Indigneous or Other" "Pichincha" "Napo or Orellana"
mat colnames y = "Sample Size" "Computer" "Internet" "TV" "Radio" "Computer & Internet" "p-value" 
mat2txt, matrix(y) saving("output/Table1_Access.xls") format(%9.0f %9.2f %9.2f %9.2f %9.2f %9.2f %9.3f) replace
restore

************ Are they using online or tele-educative content, and who is not using it? *************


*** Use of different online or teleducative content
* Done any online learning or tele-educative content in last 7 days
gen anylearning=cond(S5==1,1,0) if S5~=.
label var anylearning "Any online or tele-educative learning"

*** What tools are they using?
* how many say they use the fake platform
fre S6_3
gen UseEduca=1 if S6_1==1 & S6_3~=1
replace UseEduca=0 if S6_1==2|(S6_1==1 & S6_3==1)|anylearning==0
replace UseEduca=1 if (CODS6OTH1==12|CODS6OTH2==12) 
label var UseEduca "Uses Educa"
gen UseDOV=1 if S6_2==1 & S6_3~=1
replace UseDOV=0 if S6_2==2|(S6_2==1 & S6_3==1)|anylearning==0
label var UseDOV "Uses DOV"
gen UseYouTube=1 if S6_4==1 & S6_3~=1
replace UseYouTube=0 if S6_4==2|(S6_4==1 & S6_3==1)|anylearning==0
label var UseYouTube "Uses YouTube"
gen UseClassroomZoom=1 if S6_6==1 & S6_3~=1
replace UseClassroomZoom=0 if S6_6==2|(S6_6==1 & S6_3==1)|anylearning==0
replace UseClassroomZoom=1 if (CODS6OTH1==6|CODS6OTH2==6) 
label var UseClassroom "Uses Google Classroom or Zoom"
gen UseEdModo=1 if S6_7==1 & S6_3~=1
replace UseEdModo=0 if S6_7==2|(S6_7==1 & S6_3==1)|anylearning==0
replace UseEdModo=1 if (CODS6OTH1==7|CODS6OTH2==7) 
label var UseEdModo"Uses EdModo"
sum Use*

*** What have teachers done
gen teachersonlineclass=cond(S7_1==1,1,0) if S7_1~=.
label var teachersonlineclass "Teachers have held online class"
gen teacherssentmaterials=cond(S7_2==1,1,0) if S7_2~=.
label var teacherssentmaterials "Teachers have sent learning materials"
gen teachersethomework=cond(S7_3==1,1,0) if S7_3~=.
label var teachersethomework "Teachers have set homework"
sum teachers*


* Indicator of those with no internet access
gen nointernet=internet==0

****** TABLE 2: Use of Remote Learning *****************************************
preserve 
keep if answersurvey==1
mat y = J(23,10,.)
*** Overall Sample
count if allsample==1
mat y[1,1]=r(N)
local i=2
foreach zar of varlist anylearning UseEduca UseDOV UseYouTube UseClassroomZoom UseEdModo teachersonlineclass teacherssentmaterial teachersethomework {
    sum `zar'
	mat y[1,`i']=r(mean)
local i=`i'+1
}
* Means By Socioeconomic Characteristic
local j=2
foreach var of varlist male female female grade1 grade2 grade3 grade3 iq1 iq4 iq4 loweduc higheduc higheduc mestizowhite otherethnic otherethnic Pichincha NaOrellana NaOrellana haveaccess nointernet nointernet {
count if allsample==1 & `var'==1
mat y[`j',1]=r(N)
local i=2
foreach zar of varlist anylearning UseEduca UseDOV UseYouTube UseClassroomZoom UseEdModo teachersonlineclass teacherssentmaterial teachersethomework {
    sum `zar' if `var'==1
	mat y[`j',`i']=r(mean)
local i=`i'+1
}
local j=`j'+1
}

* Tests of Equality by Characteristic
* Gender 
mat y[4,1]=.
local i=2
foreach zar of varlist anylearning UseEduca UseDOV UseYouTube UseClassroomZoom UseEdModo teachersonlineclass teacherssentmaterial teachersethomework {
    ttest `zar', by(male)
	mat y[4,`i']=r(p)
local i=`i'+1
}
* Grade 
mat y[8,1]=.
local i=2
foreach zar of varlist anylearning UseEduca UseDOV UseYouTube UseClassroomZoom UseEdModo teachersonlineclass teacherssentmaterial teachersethomework {
    reg `zar' grade1 grade2, r
	test _b[grade1]==_b[grade2]==0
	mat y[8,`i']=r(p)
local i=`i'+1
}
* Wealth Equality
mat y[11,1]=.
local i=2
foreach zar of varlist anylearning UseEduca UseDOV UseYouTube UseClassroomZoom UseEdModo teachersonlineclass teacherssentmaterial teachersethomework {
    ttest `zar' if iq1==1|iq4==1, by(iq1)
	mat y[11,`i']=r(p)
local i=`i'+1
}
* Education Equality
mat y[14,1]=.
local i=2
foreach zar of varlist anylearning UseEduca UseDOV UseYouTube UseClassroomZoom UseEdModo teachersonlineclass teacherssentmaterial teachersethomework {
    ttest `zar', by(higheduc)
	mat y[14,`i']=r(p)
local i=`i'+1
}
* Ethnic Equality
mat y[17,1]=.
local i=2
foreach zar of varlist anylearning UseEduca UseDOV UseYouTube UseClassroomZoom UseEdModo teachersonlineclass teacherssentmaterial teachersethomework {
    ttest `zar', by(otherethnic)
	mat y[17,`i']=r(p)
local i=`i'+1
}
* Provincial Equality
mat y[20,1]=.
local i=2
foreach zar of varlist anylearning UseEduca UseDOV UseYouTube UseClassroomZoom UseEdModo teachersonlineclass teacherssentmaterial teachersethomework {
    ttest `zar', by(NaOrellana)
	mat y[20,`i']=r(p)
local i=`i'+1
}
* Access to Internet Equality
mat y[23,1]=.
local i=2
foreach zar of varlist anylearning UseEduca UseDOV UseYouTube UseClassroomZoom UseEdModo teachersonlineclass teacherssentmaterial teachersethomework {
    ttest `zar' if haveaccess==1|nointernet==1, by(nointernet)
	mat y[23,`i']=r(p)
local i=`i'+1
}

mat rownames y = "Full Sample" "Males" "Females" " Testing Gender Equality" "Grade 10" "Grade 11" "Grade 12" " Testing Grade Equality" "Lowest Wealth Quartile" "Highest Wealth Quartile" " Testing Wealth Equality" "Mother's Education: high school or less" "Mother's education: beyond high school" " Testing Educational Equality" "Mestizo or White" "Indigneous or Other" " Testing Ethnicity Equality"  "Pichincha" "Napo or Orellana" " Testing Provincial Equality" "Have Computer & Internet" "No Internet" " Testing Internet Access Equality"
mat colnames y = "Sample Size" "Any Remote Learning" "Educa" "DOV" "YouTube" "Google Classroom/Zoom" "EdModo" "Teacher Online Class" "Teacher Materials" "Teacher Homework"
mat2txt, matrix(y) saving("output/Table2_Usage.xls") format(%9.0f %9.3f) replace
restore

****** Inverse Probability Weighting Adjusted Estimates - for calculation in endnote 2.
probit answersurvey female I_Agey iq1 iq2 iq3 loweduc otherethnic Napo Orellana havephone dadphone mumphone  grade2 grade3  I_Language_Solo_lengua_nativa, r
predict probanswer

sum haveaccess anylearning if answersurvey==1
reg haveaccess if answersurvey==1, r
reg haveaccess if answersurvey==1 [pweight=1/probanswer]
reg anylearning if answersurvey==1 [pweight=1/probanswer]


**************************************************************************************************************
****** SECTION 4: TIME-USE ***********************************************************************************
**************************************************************************************************************

**** Time use

**** Code up  all activities  ******
forvalues i = 1(1)31 {
gen timeuse`i'_400=cond(S1_1_1==`i'|S1_1_2==`i',1,0) if S1_1_1~=.
gen timeuse`i'_430=cond(S1_2_1==`i'|S1_2_2==`i',1,0) if S1_2_1~=.
gen timeuse`i'_500=cond(S1_3_1==`i'|S1_3_2==`i',1,0) if S1_3_1~=.
gen timeuse`i'_530=cond(S1_4_1==`i'|S1_4_2==`i',1,0) if S1_4_1~=.
gen timeuse`i'_600=cond(S1_5_1==`i'|S1_5_2==`i',1,0) if S1_5_1~=.
gen timeuse`i'_630=cond(S1_6_1==`i'|S1_6_2==`i',1,0) if S1_6_1~=.
gen timeuse`i'_700=cond(S1_7_1==`i'|S1_7_2==`i',1,0) if S1_7_1~=.
gen timeuse`i'_730=cond(S1_8_1==`i'|S1_8_2==`i',1,0) if S1_8_1~=.
gen timeuse`i'_800=cond(S1_9_1==`i'|S1_9_2==`i',1,0) if S1_9_1~=.
gen timeuse`i'_830=cond(S1_10_1==`i'|S1_10_2==`i',1,0) if S1_10_1~=.
gen timeuse`i'_900=cond(S1B_11_1==`i'|S1B_11_2==`i',1,0) if S1B_11_1~=.
gen timeuse`i'_930=cond(S1B_12_1==`i'|S1B_12_2==`i',1,0) if S1B_12_1~=.
gen timeuse`i'_1000=cond(S1B_13_1==`i'|S1B_13_2==`i',1,0) if S1B_13_1~=.
gen timeuse`i'_1030=cond(S1B_14_1==`i'|S1B_14_2==`i',1,0) if S1B_14_1~=.
gen timeuse`i'_1100=cond(S1B_15_1==`i'|S1B_15_2==`i',1,0) if S1B_15_1~=.
gen timeuse`i'_1130=cond(S1B_16_1==`i'|S1B_16_2==`i',1,0) if S1B_16_1~=.
gen timeuse`i'_1200=cond(S1B_17_1==`i'|S1B_17_2==`i',1,0) if S1B_17_1~=.
gen timeuse`i'_1230=cond(S1B_18_1==`i'|S1B_18_2==`i',1,0) if S1B_18_1~=.
gen timeuse`i'_1300=cond(S1B_19_1==`i'|S1B_19_2==`i',1,0) if S1B_19_1~=.
gen timeuse`i'_1330=cond(S1B_20_1==`i'|S1B_20_2==`i',1,0) if S1B_20_1~=.
gen timeuse`i'_1400=cond(S1C_21_1==`i'|S1C_21_2==`i',1,0) if S1C_21_1~=.
gen timeuse`i'_1430=cond(S1C_22_1==`i'|S1C_22_2==`i',1,0) if S1C_22_1~=.
gen timeuse`i'_1500=cond(S1C_23_1==`i'|S1C_23_2==`i',1,0) if S1C_23_1~=.
gen timeuse`i'_1530=cond(S1C_24_1==`i'|S1C_24_2==`i',1,0) if S1C_24_1~=.
gen timeuse`i'_1600=cond(S1C_25_1==`i'|S1C_25_2==`i',1,0) if S1C_25_1~=.
gen timeuse`i'_1630=cond(S1C_26_1==`i'|S1C_26_2==`i',1,0) if S1C_26_1~=.
gen timeuse`i'_1700=cond(S1C_27_1==`i'|S1C_27_2==`i',1,0) if S1C_27_1~=.
gen timeuse`i'_1730=cond(S1C_28_1==`i'|S1C_28_2==`i',1,0) if S1C_28_1~=.
gen timeuse`i'_1800=cond(S1C_29_1==`i'|S1C_29_2==`i',1,0) if S1C_29_1~=.
gen timeuse`i'_1830=cond(S1C_30_1==`i'|S1C_30_2==`i',1,0) if S1C_30_1~=.
gen timeuse`i'_1900=cond(S1D_31_1==`i'|S1D_31_2==`i',1,0) if S1D_31_1~=.
gen timeuse`i'_1930=cond(S1D_32_1==`i'|S1D_32_2==`i',1,0) if S1D_32_1~=.
gen timeuse`i'_2000=cond(S1D_33_1==`i'|S1D_33_2==`i',1,0) if S1D_33_1~=.
gen timeuse`i'_2030=cond(S1D_34_1==`i'|S1D_34_2==`i',1,0) if S1D_34_1~=.
gen timeuse`i'_2100=cond(S1D_35_1==`i'|S1D_35_2==`i',1,0) if S1D_35_1~=.
gen timeuse`i'_2130=cond(S1D_36_1==`i'|S1D_36_2==`i',1,0) if S1D_36_1~=.
gen timeuse`i'_2200=cond(S1D_37_1==`i'|S1D_37_2==`i',1,0) if S1D_37_1~=.
gen timeuse`i'_2230=cond(S1D_38_1==`i'|S1D_38_2==`i',1,0) if S1D_38_1~=.
gen timeuse`i'_2300=cond(S1D_39_1==`i'|S1D_39_2==`i',1,0) if S1D_39_1~=.
gen timeuse`i'_2330=cond(S1D_40_1==`i'|S1D_40_2==`i',1,0) if S1D_40_1~=.
gen timeuse`i'_2400=cond(S1E_41_1==`i'|S1E_41_2==`i',1,0) if S1E_41_1~=.
gen timeuse`i'_30=cond(S1E_42_1==`i'|S1E_42_2==`i',1,0) if S1E_42_1~=.
gen timeuse`i'_100=cond(S1E_43_1==`i'|S1E_43_2==`i',1,0) if S1E_43_1~=.
gen timeuse`i'_130=cond(S1E_44_1==`i'|S1E_44_2==`i',1,0) if S1E_44_1~=.
gen timeuse`i'_200=cond(S1E_45_1==`i'|S1E_45_2==`i',1,0) if S1E_45_1~=.
gen timeuse`i'_230=cond(S1E_46_1==`i'|S1E_46_2==`i',1,0) if S1E_46_1~=.
gen timeuse`i'_300=cond(S1E_47_1==`i'|S1E_47_2==`i',1,0) if S1E_47_1~=.
gen timeuse`i'_330=cond(S1E_48_1==`i'|S1E_48_2==`i',1,0) if S1E_48_1~=.
gen totaltimeuse`i'=0
foreach var of varlist timeuse`i'_400-timeuse`i'_330 {
	replace totaltimeuse`i'=totaltimeuse`i'+0.5 if `var'==1
}
}
sum totaltimeuse* if answersurvey==1 & S1_1_1~=.

***** Consistency in Time Use Reporting **************
gen directtime=S8_1 +(S8_2/60)
corr directtime totaltimeuse17 if answersurvey==1 

****** Figure 1: Histogram of Time Use on Educational Activities *******
*** Exclude Weekend days 
preserve
keep if answersurvey==1
gen weekend=1 if dayinterview==5|dayinterview==6|dayinterview==12|dayinterview==13|dayinterview==19|dayinterview==20|dayinterview==26|dayinterview==27|dayinterview==33
replace weekend=0 if weekend==.
reg totaltimeuse17 weekend 
* drop weekend days
drop if weekend==1
sum totaltimeuse17 if answersurvey==1 & haveaccess==1, de
sum totaltimeuse17 if answersurvey==1 & nointernet==1, de
twoway (histogram totaltimeuse17 if answersurvey==1 & haveaccess==1 & totaltimeuse17<=14, fcolor(none) lcolor(black) start(0) width(1) xtick(1 2 3 4 5 6 7 8 9 10) xlabel(0 2 4 6 8 10 12 14) xtitle("Hours in day spent doing schoolwork") ytitle("Proportion")) (histogram totaltimeuse17 if answersurvey==1 & nointernet==1 & totaltimeuse17<=14, start(0)  width(1) color(blue%30)), legend(order(1 "Have Computer & Internet" 2 "No Internet")) saving("output/Figure1.gph", replace) graphregion(fcolor(white))
graph export "output/Figure1.pdf", replace
restore


*** Table 3: Characteristics by Time Use ***********
preserve 
keep if answersurvey==1
gen weekend=1 if dayinterview==5|dayinterview==6|dayinterview==12|dayinterview==13|dayinterview==19|dayinterview==20|dayinterview==26|dayinterview==27|dayinterview==33
replace weekend=0 if weekend==.
* drop weekend days
drop if weekend==1

gen noschoolhours=totaltimeuse17==0
gen schoollessthan4=totaltimeuse17>0 & totaltimeuse17<=4
gen schoolmorethan4=totaltimeuse17>4 & totaltimeuse17~=.
gen reader=totaltimeuse14>0 & totaltimeuse14~=.

*** Summarize 
mat y = J(23,5,.)
count if allsample==1
mat y[1,1]=r(N)
sum noschoolhours
mat y[1,2]=r(mean)
sum schoollessthan4
mat y[1,3]=r(mean)
sum schoolmorethan4
mat y[1,4]=r(mean)
sum reader
mat y[1,5]=r(mean)
local j=2
foreach var of varlist male female female grade1 grade2 grade3 grade3 iq1 iq4 iq4 loweduc higheduc higheduc mestizowhite otherethnic otherethnic Pichincha NaOrellana NaOrellana haveaccess nointernet nointernet {
count if `var'==1
mat y[`j',1]=r(N)
sum noschoolhours if `var'==1
mat y[`j',2]=r(mean)
sum schoollessthan4 if `var'==1
mat y[`j',3]=r(mean)
sum schoolmorethan4 if `var'==1
mat y[`j',4]=r(mean)
sum reader if `var'==1
mat y[`j',5]=r(mean)
local j=`j'+1
}
* Tests of Equality by Characteristic
* Gender 
mat y[4,1]=.
local i=2
foreach zar of varlist noschoolhours schoollessthan4 schoolmorethan4 reader {
    ttest `zar', by(male)
	mat y[4,`i']=r(p)
local i=`i'+1
}
* Grade 
mat y[8,1]=.
local i=2
foreach zar of varlist noschoolhours schoollessthan4 schoolmorethan4 reader  {
    reg `zar' grade1 grade2, r
	test _b[grade1]==_b[grade2]==0
	mat y[8,`i']=r(p)
local i=`i'+1
}
* Wealth Equality
mat y[11,1]=.
local i=2
foreach zar of varlist noschoolhours schoollessthan4 schoolmorethan4 reader {
    ttest `zar' if iq1==1|iq4==1, by(iq1)
	mat y[11,`i']=r(p)
local i=`i'+1
}
* Education Equality
mat y[14,1]=.
local i=2
foreach zar of varlist noschoolhours schoollessthan4 schoolmorethan4 reader {
    ttest `zar', by(higheduc)
	mat y[14,`i']=r(p)
local i=`i'+1
}
* Ethnic Equality
mat y[17,1]=.
local i=2
foreach zar of varlist noschoolhours schoollessthan4 schoolmorethan4 reader {
    ttest `zar', by(otherethnic)
	mat y[17,`i']=r(p)
local i=`i'+1
}
* Provincial Equality
mat y[20,1]=.
local i=2
foreach zar of varlist noschoolhours schoollessthan4 schoolmorethan4 reader {
    ttest `zar', by(NaOrellana)
	mat y[20,`i']=r(p)
local i=`i'+1
}
* Access to Internet Equality
mat y[23,1]=.
local i=2
foreach zar of varlist noschoolhours schoollessthan4 schoolmorethan4 reader {
    ttest `zar' if haveaccess==1|nointernet==1, by(nointernet)
	mat y[23,`i']=r(p)
local i=`i'+1
}

mat rownames y = "Full Sample" "Males" "Females" " Testing Gender Equality" "Grade 10" "Grade 11" "Grade 12" " Testing Grade Equality" "Lowest Wealth Quartile" "Highest Wealth Quartile" " Testing Wealth Equality" "Mother's Education: high school or less" "Mother's education: beyond high school" " Testing Educational Equality" "Mestizo or White" "Indigneous or Other" " Testing Ethnicity Equality"  "Pichincha" "Napo or Orellana" " Testing Provincial Equality" "Have Computer & Internet" "No Internet" " Testing Internet Access Equality"
mat colnames y = "Sample Size" "No Schoolwork" "0.5-4 hours" ">4 hours" "Reads"
mat2txt, matrix(y) saving("output/Table3Who.xls") format(%9.0f %9.3f %9.3f %9.3f %9.3f %9.3f) replace
restore

**** Figure 2: Aggregated Time-Use by Wealth Quartile *************

preserve
keep if answersurvey==1 & S1_1_1~=.

*** Any form of working or looking for work
forvalues i= 30(100)2330 {
egen work_`i'=rowmax(timeuse4_`i' timeuse5_`i' timeuse6_`i')	
}
forvalues i= 100(100)2400 {
egen work_`i'=rowmax(timeuse4_`i' timeuse5_`i' timeuse6_`i')	
}

*** Any household tasks
forvalues i= 30(100)2330 {
egen hhtask_`i'=rowmax(timeuse7_`i' timeuse9_`i' timeuse10_`i' timeuse11_`i' timeuse13_`i')	
}
forvalues i= 100(100)2400 {
egen hhtask_`i'=rowmax(timeuse7_`i' timeuse9_`i' timeuse10_`i' timeuse11_`i' timeuse13_`i')	
}

**** Any education
forvalues i= 30(100)2330 {
egen anyeduc_`i'=rowmax(timeuse14_`i' timeuse15_`i' timeuse16_`i' timeuse17_`i')	
}
forvalues i= 100(100)2400 {
egen anyeduc_`i'=rowmax(timeuse14_`i' timeuse15_`i' timeuse16_`i' timeuse17_`i')	
}

*** Any leisure
forvalues i= 30(100)2330 {
egen leisure_`i'=rowmax(timeuse19_`i' timeuse20_`i' timeuse21_`i' timeuse22_`i' timeuse23_`i' timeuse3_`i')	
}
forvalues i= 100(100)2400 {
egen leisure_`i'=rowmax(timeuse19_`i' timeuse20_`i' timeuse21_`i' timeuse22_`i' timeuse23_`i' timeuse3_`i')		
}

collapse (mean) timeuse* work_* hhtask_* anyeduc_* leisure_*, by(incquart)

gen obs=_n
reshape long timeuse1_ timeuse2_ timeuse3_ timeuse4_ timeuse5_ timeuse6_ timeuse7_ timeuse8_ timeuse9_ timeuse10_ timeuse11_ timeuse12_ timeuse13_ timeuse14_ timeuse15_ timeuse16_ timeuse17_ timeuse18_ timeuse19_ timeuse20_ timeuse21_ timeuse22_ timeuse23_ timeuse24_ timeuse25_ timeuse26_ timeuse27_ work_ hhtask_ anyeduc_ leisure_, i(incquart) j(hour)

gen sleep=timeuse1_
gen personalcare=timeuse2_
gen watchtv=timeuse3_
gen workfamilybus=timeuse4_
gen workotherjob=timeuse5_
gen lookforwork=timeuse6_
gen preparemeals=timeuse7_
gen eat=timeuse8_
gen cleankitchen=timeuse9_
gen laundry=timeuse10_
gen buyfood=timeuse11_
gen religion=timeuse12_
gen helpsiblings=timeuse13_
gen read=timeuse14_
gen watchlisteneduc=timeuse15_
gen learnuniversityoptions=timeuse16_
gen schoolwork=timeuse17_
gen businessidea=timeuse18_
gen musicinstrument=timeuse19_
gen hobbyorsport=timeuse20_
gen gooutwithfriends=timeuse21_
gen onlinewithfriends=timeuse22_
gen playonline=timeuse23_
gen transport=timeuse24_


foreach var of varlist sleep work_ hhtask_ anyeduc_ leisure_ {
	gen `var'_iq1=`var' if incquart==1
	gen `var'_iq2=`var' if incquart==2
	gen `var'_iq3=`var' if incquart==3
	gen `var'_iq4=`var' if incquart==4
	label var `var'_iq1 "Lowest Quartile"
	label var `var'_iq2 "Quartile 2"
	label var `var'_iq3 "Quartile 3"
	label var `var'_iq4 "Quartile 4"
}

* Sleeping
twoway line sleep_iq1 sleep_iq2 sleep_iq3 sleep_iq4 hour, xtitle("Time of Day") ytitle("Proportion") xlabel(0 400 800 1200 1600 2000 2400) xtick(200 600 1000 1400 1800 2200) title("Sleeping") saving("Time1iq.gph", replace) legend(off) lcolor(red ltblue midblue blue) lpattern(l l l _) lwidth(medium thin thin medium) graphregion(fcolor(white))

* Working
twoway line work__iq1 work__iq2 work__iq3 work__iq4 hour, xtitle("Time of Day") ytitle("Proportion") xlabel(0 400 800 1200 1600 2000 2400) xtick(200 600 1000 1400 1800 2200) title("Working") saving("Time2iq.gph", replace) legend(off) lcolor(red ltblue midblue blue) lpattern(l l l _) lwidth(medium thin thin medium) graphregion(fcolor(white))

* Household Tasks
twoway line hhtask__iq1 hhtask__iq2 hhtask__iq3 hhtask__iq4 hour, xtitle("Time of Day") ytitle("Proportion") xlabel(0 400 800 1200 1600 2000 2400) xtick(200 600 1000 1400 1800 2200) title("Household Tasks") saving("Time3iq.gph", replace) legend(off) lcolor(red ltblue midblue blue) lpattern(l l l _) lwidth(medium thin thin medium) graphregion(fcolor(white))

* Education
twoway line anyeduc__iq1 anyeduc__iq2 anyeduc__iq3 anyeduc__iq4 hour, xtitle("Time of Day") ytitle("Proportion") xlabel(0 400 800 1200 1600 2000 2400) xtick(200 600 1000 1400 1800 2200) title("Education") saving("Time4iq.gph", replace) legend(off) lcolor(red ltblue midblue blue) lpattern(l l l _) lwidth(medium thin thin medium) graphregion(fcolor(white))

* Leisure
twoway line leisure__iq1 leisure__iq2 leisure__iq3 leisure__iq4 hour, xtitle("Time of Day") ytitle("Proportion") xlabel(0 400 800 1200 1600 2000 2400) xtick(200 600 1000 1400 1800 2200) title("Leisure") saving("Time5iq.gph", replace) legend(off) lcolor(red ltblue midblue blue) lpattern(l l l _) lwidth(medium thin thin medium) graphregion(fcolor(white))

* Graph with legend
twoway line leisure__iq1 leisure__iq2 leisure__iq3 leisure__iq4 hour, xtitle("Time of Day") ytitle("Proportion") xlabel(0 400 800 1200 1600 2000 2400) xtick(200 600 1000 1400 1800 2200) title("Leisure") saving("Time5iq1.gph", replace) lcolor(red ltblue midblue blue) lpattern(l l l _) lwidth(medium thin thin medium) graphregion(fcolor(white))
graph combine "Time1iq.gph" "Time2iq.gph" "Time3iq.gph" "Time4iq.gph" "Time5iq.gph" "Time5iq1.gph", row(2) graphregion(fcolor(white)) saving("output/Figure2.gph", replace)

gr_edit plotregion1.graph6.plotregion1.draw_view.setstyle, style(no)
gr_edit plotregion1.graph6.xaxis1.draw_view.setstyle, style(no)
gr_edit plotregion1.graph6.yaxis1.draw_view.setstyle, style(no)
gr_edit plotregion1.graph6.title.draw_view.setstyle, style(no)
gr_edit plotregion1.graph6.legend.Edit , style(cols(1)) style(rows(0)) keepstyles 
gr_edit plotregion1.graph6.legend.DragBy 15.65534591745801 1.86112503913836

gr_edit plotregion1.graph1.xaxis1.style.editstyle majorstyle(tickstyle(textstyle(size(small)))) editcopy
gr_edit plotregion1.graph2.xaxis1.style.editstyle majorstyle(tickstyle(textstyle(size(small)))) editcopy
gr_edit plotregion1.graph3.xaxis1.style.editstyle majorstyle(tickstyle(textstyle(size(small)))) editcopy
gr_edit plotregion1.graph4.xaxis1.style.editstyle majorstyle(tickstyle(textstyle(size(small)))) editcopy
gr_edit plotregion1.graph5.xaxis1.style.editstyle majorstyle(tickstyle(textstyle(size(small)))) editcopy
graph save "output/Figure2.gph", replace
graph export "output/Figure2.pdf", replace
graph export "output/Figure2.png", replace
restore

**** Figure 3: Aggregated Time-Use by Gender *************

preserve
keep if answersurvey==1 & S1_1_1~=.

*** Any form of working or looking for work
forvalues i= 30(100)2330 {
egen work_`i'=rowmax(timeuse4_`i' timeuse5_`i' timeuse6_`i')	
}
forvalues i= 100(100)2400 {
egen work_`i'=rowmax(timeuse4_`i' timeuse5_`i' timeuse6_`i')	
}

*** Any household tasks
forvalues i= 30(100)2330 {
egen hhtask_`i'=rowmax(timeuse7_`i' timeuse9_`i' timeuse10_`i' timeuse11_`i' timeuse13_`i')	
}
forvalues i= 100(100)2400 {
egen hhtask_`i'=rowmax(timeuse7_`i' timeuse9_`i' timeuse10_`i' timeuse11_`i' timeuse13_`i')	
}

**** Any education
forvalues i= 30(100)2330 {
egen anyeduc_`i'=rowmax(timeuse14_`i' timeuse15_`i' timeuse16_`i' timeuse17_`i')	
}
forvalues i= 100(100)2400 {
egen anyeduc_`i'=rowmax(timeuse14_`i' timeuse15_`i' timeuse16_`i' timeuse17_`i')	
}

*** Any leisure
forvalues i= 30(100)2330 {
egen leisure_`i'=rowmax(timeuse19_`i' timeuse20_`i' timeuse21_`i' timeuse22_`i' timeuse23_`i' timeuse3_`i')	
}
forvalues i= 100(100)2400 {
egen leisure_`i'=rowmax(timeuse19_`i' timeuse20_`i' timeuse21_`i' timeuse22_`i' timeuse23_`i' timeuse3_`i')		
}

collapse (mean) timeuse* work_* hhtask_* anyeduc_* leisure_*, by(male)

gen obs=_n
reshape long timeuse1_ timeuse2_ timeuse3_ timeuse4_ timeuse5_ timeuse6_ timeuse7_ timeuse8_ timeuse9_ timeuse10_ timeuse11_ timeuse12_ timeuse13_ timeuse14_ timeuse15_ timeuse16_ timeuse17_ timeuse18_ timeuse19_ timeuse20_ timeuse21_ timeuse22_ timeuse23_ timeuse24_ timeuse25_ timeuse26_ timeuse27_ work_ hhtask_ anyeduc_ leisure_, i(male) j(hour)

gen sleep=timeuse1_
gen personalcare=timeuse2_
gen watchtv=timeuse3_
gen workfamilybus=timeuse4_
gen workotherjob=timeuse5_
gen lookforwork=timeuse6_
gen preparemeals=timeuse7_
gen eat=timeuse8_
gen cleankitchen=timeuse9_
gen laundry=timeuse10_
gen buyfood=timeuse11_
gen religion=timeuse12_
gen helpsiblings=timeuse13_
gen read=timeuse14_
gen watchlisteneduc=timeuse15_
gen learnuniversityoptions=timeuse16_
gen schoolwork=timeuse17_
gen businessidea=timeuse18_
gen musicinstrument=timeuse19_
gen hobbyorsport=timeuse20_
gen gooutwithfriends=timeuse21_
gen onlinewithfriends=timeuse22_
gen playonline=timeuse23_
gen transport=timeuse24_


foreach var of varlist sleep work_ hhtask_ anyeduc_ leisure_ {
	gen `var'_male=`var' if male==1
	gen `var'_female=`var' if male==0
	label var `var'_male "Male"
	label var `var'_female "Female"
}

* Sleeping
twoway line sleep_male sleep_female hour, xtitle("Time of Day") ytitle("Proportion") xlabel(0 400 800 1200 1600 2000 2400) xtick(200 600 1000 1400 1800 2200) title("Sleeping") saving("Time1m.gph", replace) legend(off) lcolor(blue  red) lpattern(l _) lwidth(medium medium) graphregion(fcolor(white))

* Working
twoway line work__male work__female hour, xtitle("Time of Day") ytitle("Proportion") xlabel(0 400 800 1200 1600 2000 2400) xtick(200 600 1000 1400 1800 2200) title("Working") saving("Time2m.gph", replace) legend(off) lcolor(blue  red) lpattern(l _) lwidth(medium medium) graphregion(fcolor(white))

* Household Tasks
twoway line hhtask__male hhtask__female  hour, xtitle("Time of Day") ytitle("Proportion") xlabel(0 400 800 1200 1600 2000 2400) xtick(200 600 1000 1400 1800 2200) title("Household Tasks") saving("Time3m.gph", replace) legend(off) lcolor(blue  red) lpattern(l _) lwidth(medium medium) graphregion(fcolor(white))

* Education
twoway line anyeduc__male anyeduc__female  hour, xtitle("Time of Day") ytitle("Proportion") xlabel(0 400 800 1200 1600 2000 2400) xtick(200 600 1000 1400 1800 2200) title("Education") saving("Time4m.gph", replace) legend(off) lcolor(blue  red) lpattern(l _) lwidth(medium medium) graphregion(fcolor(white))

* Leisure
twoway line leisure__male leisure__female  hour, xtitle("Time of Day") ytitle("Proportion") xlabel(0 400 800 1200 1600 2000 2400) xtick(200 600 1000 1400 1800 2200) title("Leisure") saving("Time5m.gph", replace) legend(off) lcolor(blue  red) lpattern(l _) lwidth(medium medium) graphregion(fcolor(white))

* Graph with legend
twoway line leisure__male leisure__female  hour, xtitle("Time of Day") ytitle("Proportion") xlabel(0 400 800 1200 1600 2000 2400) xtick(200 600 1000 1400 1800 2200) title("Leisure") saving("Time5m1.gph", replace) lcolor(blue  red) lpattern(l _) lwidth(medium medium) graphregion(fcolor(white))
graph combine "Time1m.gph" "Time2m.gph" "Time3m.gph" "Time4m.gph" "Time5m.gph" "Time5m1.gph", row(2) graphregion(fcolor(white))

gr_edit plotregion1.graph6.plotregion1.draw_view.setstyle, style(no)
gr_edit plotregion1.graph6.xaxis1.draw_view.setstyle, style(no)
gr_edit plotregion1.graph6.yaxis1.draw_view.setstyle, style(no)
gr_edit plotregion1.graph6.title.draw_view.setstyle, style(no)
gr_edit plotregion1.graph6.legend.Edit , style(cols(1)) style(rows(0)) keepstyles 
gr_edit plotregion1.graph6.legend.DragBy 15.65534591745801 1.86112503913836

gr_edit plotregion1.graph1.xaxis1.style.editstyle majorstyle(tickstyle(textstyle(size(small)))) editcopy
gr_edit plotregion1.graph2.xaxis1.style.editstyle majorstyle(tickstyle(textstyle(size(small)))) editcopy
gr_edit plotregion1.graph3.xaxis1.style.editstyle majorstyle(tickstyle(textstyle(size(small)))) editcopy
gr_edit plotregion1.graph4.xaxis1.style.editstyle majorstyle(tickstyle(textstyle(size(small)))) editcopy
gr_edit plotregion1.graph5.xaxis1.style.editstyle majorstyle(tickstyle(textstyle(size(small)))) editcopy
graph save "output/Figure3.gph", replace
graph export "output/Figure3.pdf", replace
graph export "output/Figure3.png", replace
restore


**** Figure 4: Aggregated Time-Use by Internet Access *************

preserve
keep if answersurvey==1 & S1_1_1~=.

*** Any form of working or looking for work
forvalues i= 30(100)2330 {
egen work_`i'=rowmax(timeuse4_`i' timeuse5_`i' timeuse6_`i')	
}
forvalues i= 100(100)2400 {
egen work_`i'=rowmax(timeuse4_`i' timeuse5_`i' timeuse6_`i')	
}

*** Any household tasks
forvalues i= 30(100)2330 {
egen hhtask_`i'=rowmax(timeuse7_`i' timeuse9_`i' timeuse10_`i' timeuse11_`i' timeuse13_`i')	
}
forvalues i= 100(100)2400 {
egen hhtask_`i'=rowmax(timeuse7_`i' timeuse9_`i' timeuse10_`i' timeuse11_`i' timeuse13_`i')	
}

**** Any education
forvalues i= 30(100)2330 {
egen anyeduc_`i'=rowmax(timeuse14_`i' timeuse15_`i' timeuse16_`i' timeuse17_`i')	
}
forvalues i= 100(100)2400 {
egen anyeduc_`i'=rowmax(timeuse14_`i' timeuse15_`i' timeuse16_`i' timeuse17_`i')	
}

*** Any leisure
forvalues i= 30(100)2330 {
egen leisure_`i'=rowmax(timeuse19_`i' timeuse20_`i' timeuse21_`i' timeuse22_`i' timeuse23_`i' timeuse3_`i')	
}
forvalues i= 100(100)2400 {
egen leisure_`i'=rowmax(timeuse19_`i' timeuse20_`i' timeuse21_`i' timeuse22_`i' timeuse23_`i' timeuse3_`i')		
}

collapse (mean) timeuse* work_* hhtask_* anyeduc_* leisure_*, by(internet)

gen obs=_n
reshape long timeuse1_ timeuse2_ timeuse3_ timeuse4_ timeuse5_ timeuse6_ timeuse7_ timeuse8_ timeuse9_ timeuse10_ timeuse11_ timeuse12_ timeuse13_ timeuse14_ timeuse15_ timeuse16_ timeuse17_ timeuse18_ timeuse19_ timeuse20_ timeuse21_ timeuse22_ timeuse23_ timeuse24_ timeuse25_ timeuse26_ timeuse27_ work_ hhtask_ anyeduc_ leisure_, i(internet) j(hour)

gen sleep=timeuse1_
gen personalcare=timeuse2_
gen watchtv=timeuse3_
gen workfamilybus=timeuse4_
gen workotherjob=timeuse5_
gen lookforwork=timeuse6_
gen preparemeals=timeuse7_
gen eat=timeuse8_
gen cleankitchen=timeuse9_
gen laundry=timeuse10_
gen buyfood=timeuse11_
gen religion=timeuse12_
gen helpsiblings=timeuse13_
gen read=timeuse14_
gen watchlisteneduc=timeuse15_
gen learnuniversityoptions=timeuse16_
gen schoolwork=timeuse17_
gen businessidea=timeuse18_
gen musicinstrument=timeuse19_
gen hobbyorsport=timeuse20_
gen gooutwithfriends=timeuse21_
gen onlinewithfriends=timeuse22_
gen playonline=timeuse23_
gen transport=timeuse24_


foreach var of varlist sleep work_ hhtask_ anyeduc_ leisure_ {
	gen `var'_internet=`var' if internet==1
	gen `var'_nointernet=`var' if internet==0
	label var `var'_internet "Internet"
	label var `var'_nointernet "No Internet"
}

* Sleeping
twoway line sleep_internet sleep_nointernet hour, xtitle("Time of Day") ytitle("Proportion") xlabel(0 400 800 1200 1600 2000 2400) xtick(200 600 1000 1400 1800 2200) title("Sleeping") saving("Time1i.gph", replace) legend(off) lcolor(blue  red) lpattern(l _) lwidth(medium medium) graphregion(fcolor(white))

* Working
twoway line work__internet work__nointernet hour, xtitle("Time of Day") ytitle("Proportion") xlabel(0 400 800 1200 1600 2000 2400) xtick(200 600 1000 1400 1800 2200) title("Working") saving("Time2i.gph", replace) legend(off) lcolor(blue  red) lpattern(l _) lwidth(medium medium) graphregion(fcolor(white))

* Household Tasks
twoway line hhtask__internet hhtask__nointernet  hour, xtitle("Time of Day") ytitle("Proportion") xlabel(0 400 800 1200 1600 2000 2400) xtick(200 600 1000 1400 1800 2200) title("Household Tasks") saving("Time3i.gph", replace) legend(off) lcolor(blue  red) lpattern(l _) lwidth(medium medium) graphregion(fcolor(white))

* Education
twoway line anyeduc__internet anyeduc__nointernet  hour, xtitle("Time of Day") ytitle("Proportion") xlabel(0 400 800 1200 1600 2000 2400) xtick(200 600 1000 1400 1800 2200) title("Education") saving("Time4i.gph", replace) legend(off) lcolor(blue  red) lpattern(l _) lwidth(medium medium) graphregion(fcolor(white))

* Leisure
twoway line leisure__internet leisure__nointernet  hour, xtitle("Time of Day") ytitle("Proportion") xlabel(0 400 800 1200 1600 2000 2400) xtick(200 600 1000 1400 1800 2200) title("Leisure") saving("Time5i.gph", replace) legend(off) lcolor(blue  red) lpattern(l _) lwidth(medium medium) graphregion(fcolor(white))

* Graph with legend
twoway line leisure__internet leisure__nointernet  hour, xtitle("Time of Day") ytitle("Proportion") xlabel(0 400 800 1200 1600 2000 2400) xtick(200 600 1000 1400 1800 2200) title("Leisure") saving("Time5i1.gph", replace) lcolor(gs0  gs3) lcolor(blue  red) lpattern(l _) lwidth(medium medium) graphregion(fcolor(white))
graph combine "Time1i.gph" "Time2i.gph" "Time3i.gph" "Time4i.gph" "Time5i.gph" "Time5i1.gph", row(2) graphregion(fcolor(white))

gr_edit plotregion1.graph6.plotregion1.draw_view.setstyle, style(no)
gr_edit plotregion1.graph6.xaxis1.draw_view.setstyle, style(no)
gr_edit plotregion1.graph6.yaxis1.draw_view.setstyle, style(no)
gr_edit plotregion1.graph6.title.draw_view.setstyle, style(no)
gr_edit plotregion1.graph6.legend.Edit , style(cols(1)) style(rows(0)) keepstyles 
gr_edit plotregion1.graph6.legend.DragBy 15.65534591745801 1.86112503913836

gr_edit plotregion1.graph1.xaxis1.style.editstyle majorstyle(tickstyle(textstyle(size(small)))) editcopy
gr_edit plotregion1.graph2.xaxis1.style.editstyle majorstyle(tickstyle(textstyle(size(small)))) editcopy
gr_edit plotregion1.graph3.xaxis1.style.editstyle majorstyle(tickstyle(textstyle(size(small)))) editcopy
gr_edit plotregion1.graph4.xaxis1.style.editstyle majorstyle(tickstyle(textstyle(size(small)))) editcopy
gr_edit plotregion1.graph5.xaxis1.style.editstyle majorstyle(tickstyle(textstyle(size(small)))) editcopy
graph save "output/Figure4.gph", replace
graph export "output/Figure4.pdf", replace
graph export "output/Figure4.png", replace

restore

************ Figure 5: Does Time-Use Devoted to Education Fall Over Time? ************
preserve
gen surveyweek=1 if dayinterview>=0 & dayinterview<=4
replace surveyweek=2 if dayinterview>=7 & dayinterview<=11
replace surveyweek=3 if dayinterview>=14 & dayinterview<=18
replace surveyweek=4 if dayinterview>=21 & dayinterview<=25
keep if answersurvey==1 & S1_1_1

*** sum schoolwork by surveyweek
bysort surveyweek: sum totaltimeuse17, de
bysort surveyweek: sum iq1 internet

*** Any form of working or looking for work
forvalues i= 30(100)2330 {
egen work_`i'=rowmax(timeuse4_`i' timeuse5_`i' timeuse6_`i')	
}
forvalues i= 100(100)2400 {
egen work_`i'=rowmax(timeuse4_`i' timeuse5_`i' timeuse6_`i')	
}

*** Any household tasks
forvalues i= 30(100)2330 {
egen hhtask_`i'=rowmax(timeuse7_`i' timeuse9_`i' timeuse10_`i' timeuse11_`i' timeuse13_`i')	
}
forvalues i= 100(100)2400 {
egen hhtask_`i'=rowmax(timeuse7_`i' timeuse9_`i' timeuse10_`i' timeuse11_`i' timeuse13_`i')	
}

**** Any education
forvalues i= 30(100)2330 {
egen anyeduc_`i'=rowmax(timeuse14_`i' timeuse15_`i' timeuse16_`i' timeuse17_`i')	
}
forvalues i= 100(100)2400 {
egen anyeduc_`i'=rowmax(timeuse14_`i' timeuse15_`i' timeuse16_`i' timeuse17_`i')	
}

*** Any leisure
forvalues i= 30(100)2330 {
egen leisure_`i'=rowmax(timeuse19_`i' timeuse20_`i' timeuse21_`i' timeuse22_`i' timeuse23_`i' timeuse3_`i')	
}
forvalues i= 100(100)2400 {
egen leisure_`i'=rowmax(timeuse19_`i' timeuse20_`i' timeuse21_`i' timeuse22_`i' timeuse23_`i' timeuse3_`i')		
}

collapse (mean) timeuse* work_* hhtask_* anyeduc_* leisure_*, by(surveyweek)

gen obs=_n
reshape long timeuse1_ timeuse2_ timeuse3_ timeuse4_ timeuse5_ timeuse6_ timeuse7_ timeuse8_ timeuse9_ timeuse10_ timeuse11_ timeuse12_ timeuse13_ timeuse14_ timeuse15_ timeuse16_ timeuse17_ timeuse18_ timeuse19_ timeuse20_ timeuse21_ timeuse22_ timeuse23_ timeuse24_ timeuse25_ timeuse26_ timeuse27_ work_ hhtask_ anyeduc_ leisure_, i(surveyweek) j(hour)

gen sleep=timeuse1_
gen personalcare=timeuse2_
gen watchtv=timeuse3_
gen workfamilybus=timeuse4_
gen workotherjob=timeuse5_
gen lookforwork=timeuse6_
gen preparemeals=timeuse7_
gen eat=timeuse8_
gen cleankitchen=timeuse9_
gen laundry=timeuse10_
gen buyfood=timeuse11_
gen religion=timeuse12_
gen helpsiblings=timeuse13_
gen read=timeuse14_
gen watchlisteneduc=timeuse15_
gen learnuniversityoptions=timeuse16_
gen schoolwork=timeuse17_
gen businessidea=timeuse18_
gen musicinstrument=timeuse19_
gen hobbyorsport=timeuse20_
gen gooutwithfriends=timeuse21_
gen onlinewithfriends=timeuse22_
gen playonline=timeuse23_
gen transport=timeuse24_


foreach var of varlist sleep work_ hhtask_ anyeduc_ leisure_ {
	gen `var'_week1=`var' if surveyweek==1
	gen `var'_week2=`var' if surveyweek==2
	gen `var'_week3=`var' if surveyweek==3
	gen `var'_week4=`var' if surveyweek==4
	label var `var'_week1 "March 30 - April 4"
	label var `var'_week2 "April 7- April 11"
	label var `var'_week3 "April 14 - April 18"
	label var `var'_week4 "April 21 - April 25"
}

* Education
twoway line anyeduc__week1 anyeduc__week2 anyeduc__week3 anyeduc__week4  hour, xtitle("Time of Day") ytitle("Proportion") xlabel(0 400 800 1200 1600 2000 2400) xtick(200 600 1000 1400 1800 2200) lcolor(gs0 gs7 gs12 gs3) lpattern(l l l _) lwidth(medium thin thin medium) graphregion(fcolor(white))

graph save "output/Figure5.gph", replace
graph export "output/Figure5.pdf", replace
graph export "output/Figure5.png", replace

restore


*****************************************************************************************************************
***** SECTION 5: MENTAL HEALTH **********************************************************************************
*****************************************************************************************************************

***** MHI-5 Mental Health Index
gen happiness=(6-Q01)
label var happiness "Happiness"
gen MHI5=(6-Q01)+(6-Q02) +Q03+Q04+Q05
label var MHI5 "Mental Health Index (MHI-5)"
gen depression=cond(MHI5<17,1,0) if MHI5~=.
label var depression "Depression"
gen happy=happiness==4|happiness==5
replace happy=. if Q01==.

sum happiness MHI5 depression if answersurvey==1, de


*** Figure 6: Graph of depression and happiness over time ***
preserve
keep if answersurvey==1
gen counter=1
collapse (mean) depression happy (sum) counter, by(dayinterview)
reg depression dayinterview if counter>=20
reg happy dayinterview if counter>=20
label var depression "Depression"
label var happy "Happy all or most of the time"
list dayinterview counter
twoway line depression happy dayinterview if counter>=20, xtitle("Date of Interview") ytitle("Proportion") scheme(s1mono) lcolor(gs0 gs3) lpattern(l _) lwidth(medium medium) saving("output/Figure6.gph", replace) graphregion(fcolor(white))
graph export "output/Figure6.pdf", replace
graph export "output/Figure6.png", replace

restore

**** Biggest Problem from Coronavirus that they currently face *******
fre Q11 if Q11~=.

gen mainstressor=1 if Q11==2|CODQ11OTH==2
replace mainstressor=2 if Q11==3|CODQ11OTH==3|CODQ11OTH==7
replace mainstressor=3 if Q11==1|CODQ11OTH==1
replace mainstressor=4 if Q11==6|CODQ11OTH==6|CODQ11OTH==11|CODQ11OTH==16
replace mainstressor=5 if Q11==5|CODQ11OTH==5|CODQ11OTH==9
replace mainstressor=6 if Q11==4|CODQ11OTH==4
replace mainstressor=7 if CODQ11OTH==1|CODQ11OTH==10|CODQ11OTH==8
replace mainstressor=8 if CODQ11OTH==15
replace mainstressor=9 if mainstressor==. & CODQ11OTH~=.

label define mainstress 1 "Social conflict" 2 "Lack of Social Contact" 3 "Internal Problems" 4 "Infrastructure" 5 "Finances" 6 "School" 7 "Health" 8 "Activities" 9 "Other"
label values mainstressor mainstress
tab mainstressor

gen stresslevelPAP=Q32_1
label var stresslevelPAP "Stress level of main stressor"

gen schoolmainproblem=cond(mainstressor==6,1,0) if mainstressor~=.
gen financesmainproblem=cond(mainstressor==5,1,0) if mainstressor~=.
gen socialmainproblem=cond(mainstressor==2,1,0) if mainstressor~=.


*** Table 4: Who is Happiest/Most Depressed/Differences in Main Problem? ***********
preserve 
keep if answersurvey==1 & MHI5~=.

*** Summarize 
mat y = J(23,6,.)
count if allsample==1
mat y[1,1]=r(N)
sum depression
mat y[1,2]=r(mean)
sum happy
mat y[1,3]=r(mean)
sum schoolmainproblem
mat y[1,4]=r(mean)
sum financesmainproblem
mat y[1,5]=r(mean)
sum socialmainproblem
mat y[1,6]=r(mean)
local j=2
foreach var of varlist male female female grade1 grade2 grade3 grade3 iq1 iq4 iq4 loweduc higheduc higheduc mestizowhite otherethnic otherethnic Pichincha NaOrellana NaOrellana haveaccess nointernet nointernet {
count if `var'==1
mat y[`j',1]=r(N)
sum depression if `var'==1
mat y[`j',2]=r(mean)
sum happy if `var'==1
mat y[`j',3]=r(mean)
sum schoolmainproblem if `var'==1
mat y[`j',4]=r(mean)
sum financesmainproblem if `var'==1
mat y[`j',5]=r(mean)
sum socialmainproblem if `var'==1
mat y[`j',6]=r(mean)
local j=`j'+1
}
* Tests of Equality by Characteristic
* Gender 
mat y[4,1]=.
local i=2
foreach zar of varlist depression happy schoolmainproblem financesmainproblem socialmainproblem {
    ttest `zar', by(male)
	mat y[4,`i']=r(p)
local i=`i'+1
}
* Grade 
mat y[8,1]=.
local i=2
foreach zar of varlist depression happy schoolmainproblem financesmainproblem socialmainproblem  {
    reg `zar' grade1 grade2, r
	test _b[grade1]==_b[grade2]==0
	mat y[8,`i']=r(p)
local i=`i'+1
}
* Wealth Equality
mat y[11,1]=.
local i=2
foreach zar of varlist depression happy schoolmainproblem financesmainproblem socialmainproblem {
    ttest `zar' if iq1==1|iq4==1, by(iq1)
	mat y[11,`i']=r(p)
local i=`i'+1
}
* Education Equality
mat y[14,1]=.
local i=2
foreach zar of varlist depression happy schoolmainproblem financesmainproblem socialmainproblem {
    ttest `zar', by(higheduc)
	mat y[14,`i']=r(p)
local i=`i'+1
}
* Ethnic Equality
mat y[17,1]=.
local i=2
foreach zar of varlist depression happy schoolmainproblem financesmainproblem socialmainproblem {
    ttest `zar', by(otherethnic)
	mat y[17,`i']=r(p)
local i=`i'+1
}
* Provincial Equality
mat y[20,1]=.
local i=2
foreach zar of varlist depression happy schoolmainproblem financesmainproblem socialmainproblem {
    ttest `zar', by(NaOrellana)
	mat y[20,`i']=r(p)
local i=`i'+1
}
* Access to Internet Equality
mat y[23,1]=.
local i=2
foreach zar of varlist depression happy schoolmainproblem financesmainproblem socialmainproblem {
    ttest `zar' if haveaccess==1|nointernet==1, by(nointernet)
	mat y[23,`i']=r(p)
local i=`i'+1
}

mat rownames y = "Full Sample" "Males" "Females" " Testing Gender Equality" "Grade 10" "Grade 11" "Grade 12" " Testing Grade Equality" "Lowest Wealth Quartile" "Highest Wealth Quartile" " Testing Wealth Equality" "Mother's Education: high school or less" "Mother's education: beyond high school" " Testing Educational Equality" "Mestizo or White" "Indigneous or Other" " Testing Ethnicity Equality"  "Pichincha" "Napo or Orellana" " Testing Provincial Equality" "Have Computer & Internet" "No Internet" " Testing Internet Access Equality"
mat colnames y = "Sample Size" "Depression" "Happy" "School" "Finances" "Social"
mat2txt, matrix(y) saving("output/Table4Mental.xls") format(%9.0f %9.3f %9.3f %9.3f %9.3f %9.3f) replace
restore


